@@ -4,7 +4,7 @@
 # Copyright (C) 2016 TADA Tadashi
 # Distributed under the GPL2 or any later version.
 #
-
+require 'tdiary/diary_container'
 
 # read cache here so that you can use category with secure mode.
 @conf['category.header1'] = ''
@@ -115,7 +115,7 @@ def category_serialize(diary)
 	diary.each_section do |s|
 		shorten = begin
 			body = %Q|apply_plugin(#{s.body_to_html.dump}, true)|
-			@conf.shorten(eval(body.untaint))
+			@conf.shorten(eval(body))
 		rescue NameError
 			""
 		end
